@@ -1,4 +1,6 @@
 # -*- coding: utf-8 -*-
+from PyQt5.QtCore import QTranslator
+
 import queue
 import sys, os, inspect
 currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
@@ -9,6 +11,7 @@ sys.path.insert(0, currentdir)
 import subprocess
 from define import *
 from communication.communication import CommunicationThread
+from off_line_handler.off_line import OffLineDetectionThread
 if sys.platform == 'linux':
     from on_off.on_off import OnOffThread
     from test_handler.test_chip_handler import TestChipHandlerThread
@@ -16,6 +19,7 @@ elif sys.platform == 'win32':
     from win_test_handler.test_chip_handler import TestChipHandlerThread
 from vkeyboard import handleVisibleChanged
 LOCAL_LAUCHER_FOLDER = '/home/pi/app/spotii/launcher'
+PROFILE_FOLDER = '/home/pi/app/spotii'
 LOCAL_LAUCHER_CHK_FILE = LOCAL_LAUCHER_FOLDER+'/chk_sum.md5'
 DESK_TOP = '/home/pi/Desktop'
 def preStart():
@@ -23,7 +27,22 @@ def preStart():
         import shutil
         os.makedirs(LOCAL_LAUCHER_FOLDER, exist_ok =True)
         os.makedirs(IMG_PATH, exist_ok =True)
-        
+
+#         cmd = 'chmod +w '+PROFILE_FOLDER
+#         subprocess.call([cmd],shell=True)
+
+        try:
+            upgrade=subprocess.check_output(['pip3','show','pytz','--disable-pip-version-check']).decode("utf-8")
+            print(upgrade)
+        except Exception as e:
+            print('pytz show exception: ',e)
+            try:
+                upgrade=subprocess.check_output(['pip3','install','pytz','--disable-pip-version-check']).decode("utf-8")
+                print(upgrade)
+            except Exception as e:
+                print('pytz install exception:',e)                
+
+
         lib_path = os.path.dirname(__file__)
         
         lib_path = '/home/pi/gxf/python/spotii_project/spotii'
@@ -31,6 +50,7 @@ def preStart():
         if lib_path == '':
             pass
         else:
+            
             upgrade_launcher = False
             if os.path.exists(LOCAL_LAUCHER_CHK_FILE):
                 with open(lib_path+'/launcher/'+'chk_sum.md5',"rb") as lib_file:
@@ -64,13 +84,15 @@ def preStart():
 import sys
 import os
 from PyQt5 import QtCore, QtGui, QtWidgets
-from guifolder.gui import MainWindow
-from main_paras import queueForGui, queueForResult, queueForCom
+
+
 
 def spot_main():
-
+    from guifolder.gui import MainWindow
+    from main_paras import queueForGui, queueForResult, queueForCom, queueForOffLine
+    import main_paras
+    
     if sys.platform == 'linux':       
-        preStart()    
         OnOff      =OnOffThread(4,"OnOff")
         OnOff.start()
 
@@ -79,8 +101,12 @@ def spot_main():
     Comm       =CommunicationThread(2,"Comm",queueForCom, queueForResult)
     Comm.start()
 
+    OffLineMonitor = OffLineDetectionThread(5,"OffLine")
+    OffLineMonitor.start()
     os.environ["QT_IM_MODULE"] = "qtvirtualkeyboard"
 
+    ##main_paras.languageInit()
+
     app = QtWidgets.QApplication(sys.argv)
     QtGui.QGuiApplication.inputMethod().visibleChanged.connect(handleVisibleChanged)
     window=MainWindow(qForGui = queueForGui)
@@ -90,11 +116,12 @@ def spot_main():
     print("App end.")
     queueForResult.put(CLOSE_NOW)
     queueForCom.put(CLOSE_NOW)
+    queueForOffLine.put(CLOSE_NOW)
     TestMonitor.join()
     window.close()
     sys.exit(rtn)
     
 if __name__ == "__main__":
-    
-#    preStart()
+    if sys.platform == 'linux':           
+        preStart()
     spot_main()
