@@ -7,7 +7,17 @@ currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentfram
 sys.path.insert(0, currentdir)
 parentdir = os.path.dirname(currentdir)
 sys.path.insert(0, parentdir)
-from SlotPage import SlotPage
+#from SlotPage import SlotPage
+from slot.scan import _Scan
+from slot.empty import _Empty
+from slot.detecting import _Detecting
+from slot.warning import _Warning
+from slot.positive import _Positive
+from slot.negative import _Negative
+from slot.invalid import _Invalid
+from slot.flip import _Flip
+from slot.invalid_qr import _Invalid_qr
+
 import title_rc
 from emit_thread import SignalThread
 #from main_paras import mainChannelNotify, getDetectionMode
@@ -29,15 +39,15 @@ class MyStackedWidget(QtWidgets.QStackedWidget):
         self.button_hooks=[None,None,None,None,None,None,self.scanHook,self.flipHook,self.invalidQrHook]
         
         self.slotBasic = [
-           ('empty.png',     None,                self.empty,),
-           ('detecting.png', None,                self.warning,),
-           ('warning.png',   None,                self.detecting,),
-           ('positive.png',  None,                self.positive,),
-           ('negative.png',  None,                self.negative,),
-           ('invalid.png',   None,                self.invalid,),
-           ('scan.png',      self.scanHook,       self.scan,),
-           ('flip.png',      self.flipHook,       self.flip,),
-           ('invalid_qr.png',self.invalidQrHook,  self.invalid_qr,),
+           (None,                self.empty,),
+           (None,                self.warning,),
+           (None,                self.detecting,),
+           (None,                self.positive,),
+           (None,                self.negative,),
+           (None,                self.invalid,),
+           (self.scanHook,       self.scan,),
+           (self.flipHook,       self.flip,),
+           (self.invalidQrHook,  self.invalid_qr,),
             ]
         self.slot_no = 0
         self.cassetteId=""
@@ -89,16 +99,16 @@ class MyStackedWidget(QtWidgets.QStackedWidget):
         print(self.slot_no, 'invalid_qr', item)
         
     def scanHook(self):
-        print('scanHook')
+        print('scanHook', self.slot_no)
         if not main_paras.signedIn():
             main_paras.queueForGui.put([SIGN_IN_FIRST_INDEX,'','',''])
             return
         setOperation(self.slot_no ,MANUAL_OPERATION_SCAN)
     def flipHook(self):
-        print('flipHook')
+        print('flipHook', self.slot_no)
         setOperation(self.slot_no ,MANUAL_OPERATION_START_TESTING)
     def invalidQrHook(self):
-        print('invalidQrHook')
+        print('invalidQrHook', self.slot_no)
         setOperation(self.slot_no ,MANUAL_OPERATION_START)
 
     def setSlotNo(self,number):
@@ -107,10 +117,8 @@ class MyStackedWidget(QtWidgets.QStackedWidget):
             self.slot_no = number
             for page in range(0, len(self.slotBasic)):
                 self.setCurrentIndex(page)
-                self.currentWidget().setDetail(self.slot_no, page)
-                style = '.QWidget{background-image:url(:/slot/png/slot/'+self.slotBasic[page][0]+ ');border:0px}'
-                self.currentWidget().background.setStyleSheet(style)
-                self.currentWidget().buttonHook(self.slotBasic[page][1])
+                self.currentWidget().setDetail(self.slot_no)
+                self.currentWidget().buttonHook(self.slotBasic[page][0])
             self.ready=True
             
             self.setCurrentIndex(0)
@@ -157,7 +165,10 @@ class MyStackedWidget(QtWidgets.QStackedWidget):
             self.cassetteId=cassette
             self.setCurrentIndex(status_index)
             page=self.currentWidget()
-            page.id.setText(self.cassetteId)
+            try:        ## some pages don't have id
+                page.id.setText(self.cassetteId)
+            except:
+                pass
             if(time!=None):
                 page.timer.setText(time) ## 1 for counting down timer
             else:
@@ -189,7 +200,7 @@ class MyStackedWidget(QtWidgets.QStackedWidget):
         
     def showDetecting(self):
         try:
-            self.setStatus(SLOT_STATUS_DETECTING, self.cassetteId, time.strftime('%M:%S', time.gmtime(self.timeIncreasing)))
+            self.setStatus(SLOT_STATUS_DETECTING, self.cassetteId, time.strftime('%-M:%S', time.gmtime(self.timeIncreasing)))
         except Exception as e:
             print(e)
     def detection_timeout(self):
@@ -204,7 +215,7 @@ class MyStackedWidget(QtWidgets.QStackedWidget):
                 self.pageParking.signal.disconnect()
             except Exception:
                 pass
-            self.pageParking.signal.connect(self.slotBasic[index][2])
+            self.pageParking.signal.connect(self.slotBasic[index][1])
             
     def totalPage(self):
         return len(self.slotBasic)
