@@ -48,7 +48,7 @@ class MyToolButton(QtWidgets.QToolButton):
     def enterEvent(self, event):
         try:
             self.enterTimeStamp=time.time()
-            print("Mouse entered",self.enterTimeStamp)
+            #print("Mouse entered",self.enterTimeStamp)
             super(MyToolButton, self).enterEvent(event)
         except Exception as e:
             print(e)
@@ -60,7 +60,7 @@ class MyToolButton(QtWidgets.QToolButton):
 ##        # emit your signal
     def leaveEvent(self, event):
         try:
-            print("Mouse left",time.time())
+            #print("Mouse left",time.time())
             super(MyToolButton, self).leaveEvent(event)
         except Exception as e:
             print(e)
@@ -95,7 +95,7 @@ class MyToolButton(QtWidgets.QToolButton):
     def notify(self):
         try:
             self.notifyTimeStamp=time.time()
-            print('got it',self.notifyTimeStamp)
+            #print('got it',self.notifyTimeStamp)
         except Exception as e:
             print(e)
     def clearNotify(self):
