@@ -23,6 +23,7 @@ import create_new_account
 import forgot_password
 import test_info
 import wrong_password
+from vkeyboard import handleVisibleChanged
 
 class _SignIn(QtWidgets.QDialog):
     def __init__(self,parent=None):
@@ -33,18 +34,37 @@ class _SignIn(QtWidgets.QDialog):
         flags = QtCore.Qt.WindowFlags(QtCore.Qt.FramelessWindowHint)
 #        flags = QtCore.Qt.WindowFlags(QtCore.Qt.FramelessWindowHint | QtCore.Qt.Popup)
         self.setWindowFlags(flags)
-        self.original = True        
+        self.last_scroll_value=0
+        self.original = True
+
+    def scrolled(self):
+        try:
+            diff =(self.last_scroll_value - self.scroll.value())*10
+            self.last_scroll_value=self.scroll.value()
+            print(self.scroll.value())
+            children= self.widget.findChildren(QtWidgets.QWidget)
+            for child in children:
+                if child != self.scroll:
+                    child.move(child.pos().x(),child.pos().y()+diff)
+            self.repaint()
+        except Exception as error:
+            print(error)
 
     def keyUp(self):
         print('keyUp got emit')
         if self.original:
             self.original = False
+            self.scroll.setVisible(True)
             self.move(0,0)
-            self.repaint()
+            self.repaint()        
 
     def config(self):
         try:
+            self.scroll.setMaximum(20)
+            self.scroll.valueChanged.connect(self.scrolled)
+            self.scroll.hide()
             main_paras.keyboard_up.signal.connect(self.keyUp)
+
             self.back.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
             self.back.clicked.connect(self.close)
             self.create_account.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
@@ -134,6 +154,7 @@ if __name__ == "__main__":
     os.environ["QT_IM_MODULE"] = "qtvirtualkeyboard"
     
     app = QtWidgets.QApplication(sys.argv)
+    QtGui.QGuiApplication.inputMethod().visibleChanged.connect(handleVisibleChanged)
 ##    app.installTranslator(trans)
 
     QtWidgets.QMainWindow
